@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.109-3-g16f93e6
+package Dist::Zilla::PluginBundle::Author::ETHER; # git description: v0.110-9-gbf3609a
 # ABSTRACT: A plugin bundle for distributions built by ETHER
 # KEYWORDS: author bundle distribution tool
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.110';
+our $VERSION = '0.111';
 
 use Moose;
 with
@@ -152,10 +152,10 @@ sub configure
         if $has_xs and not -e 'Makefile.PL';
 
     # check for a bin/ that should probably be renamed to script/
-    warn '[@Author::ETHER] ' . colored('bin/ detected - should this be moved to script/, so its contents can be installed into $PATH?', 'bright_red') . "\n"
+    warn '[@Author::ETHER] ', colored('bin/ detected - should this be moved to script/, so its contents can be installed into $PATH?', 'bright_red'), "\n"
         if -d 'bin' and any { $_ eq 'ModuleBuildTiny' } $self->installer;
 
-    warn '[@Author::ETHER] ' . colored('You are using [ModuleBuild] as an installer, WTF?!', 'bright_red') . "\n"
+    warn '[@Author::ETHER] ', colored('You are using [ModuleBuild] as an installer, WTF?!', 'bright_red'), "\n"
         if any { $_->isa('Dist::Zilla::Plugin::ModuleBuild') }
             map { Dist::Zilla::Util->expand_config_package_name($_) } $self->installer;
 
@@ -169,8 +169,8 @@ sub configure
     my $remove = $self->payload->{ $self->plugin_remover_attribute } // [];
     my %removed; @removed{@$remove} = (!!1) x @$remove;
 
-    warn '[@Author::ETHER] ' . colored('.git is missing and META.json is present -- this looks like a CPAN download rather than a git repository. You should probably run '
-            . (-f 'Build.PL' ? 'perl Build.PL; ./Build' : 'perl Makefile.PL; make') . ' instead of using dzil commands!', 'yellow') . "\n"
+    warn '[@Author::ETHER] ', colored('.git is missing and META.json is present -- this looks like a CPAN download rather than a git repository. You should probably run '
+            . (-f 'Build.PL' ? 'perl Build.PL; ./Build' : 'perl Makefile.PL; make') . ' instead of using dzil commands!', 'yellow'), "\n"
         if not -d '.git' and -f 'META.json' and not exists $removed{'Git::GatherDir'};
 
     # only set x_static_install using auto mode for my own distributions
@@ -178,6 +178,11 @@ sub configure
     my $static_install_dry_run = ($static_install_mode eq 'auto'
             and ($self->payload->{'Authority.authority'} // 'cpan:ETHER') ne 'cpan:ETHER') ? 1 : 0;
 
+    warn '[@Author::ETHER] ', colored('server = ' . $self->server
+            . ': recommend instead using server = github and GithubMeta.remote = '
+            . $self->server . ' with a read-only mirror', 'yellow'), "\n"
+        if $self->server ne 'github' and $self->server ne 'none';
+
     my @plugins = (
         # VersionProvider
         [ 'RewriteVersion::Transitional' => {
@@ -449,7 +454,7 @@ Dist::Zilla::PluginBundle::Author::ETHER - A plugin bundle for distributions bui
 
 =head1 VERSION
 
-version 0.110
+version 0.111
 
 =head1 SYNOPSIS
 
@@ -1019,7 +1024,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-L<irc://irc.perl.org/#distzilla>.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
