@@ -4,7 +4,7 @@ package Pod::Weaver::PluginBundle::Author::ETHER;
 # ABSTRACT: A plugin bundle for pod woven by ETHER
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.110';
+our $VERSION = '0.111';
 
 use namespace::autoclean -also => ['_exp'];
 use Pod::Weaver::Config::Assembler;
@@ -62,7 +62,17 @@ sub configure
     $distmeta->{resources}{x_MailingList} ? 'There is also a mailing list available for users of this distribution, at' . "\nL<" . $distmeta->{resources}{x_MailingList} . '>.' : (),
 
     $distmeta->{resources}{x_IRC}
-        ? 'There is also an irc channel available for users of this distribution, at' . "\nL<" . $distmeta->{resources}{x_IRC} . '>.'
+        ? 'There is also an irc channel available for users of this distribution, at' . "\nL<"
+            . do {
+                # try to extract the channel
+                if (my ($network, $channel) = ($distmeta->{resources}{x_IRC} =~ m!(?:://)?(\w+(?:\.\w+)*)/?(#\w+)!)) {
+                    'C<' . $channel . '> on C<' . $network . '>|' . $distmeta->{resources}{x_IRC}
+                }
+                else {
+                    $distmeta->{resources}{x_IRC}
+                }
+            }
+            . '>.'
         : (),
 
     ($distmeta->{x_authority} // '') eq 'cpan:ETHER'
@@ -74,7 +84,7 @@ SUPPORT
         ],
 
         [ 'AllowOverride' => 'allow override SUPPORT' => {
-               header_re => '^(SUPPORT|BUGS)',
+               header_re => '^(SUPPORT|BUGS)\b',
                action => 'prepend',
                match_anywhere => 0,
             },
@@ -167,7 +177,7 @@ Pod::Weaver::PluginBundle::Author::ETHER - A plugin bundle for pod woven by ETHE
 
 =head1 VERSION
 
-version 0.110
+version 0.111
 
 =head1 SYNOPSIS
 
@@ -345,7 +355,7 @@ There is also a mailing list available for users of this distribution, at
 L<http://dzil.org/#mailing-list>.
 
 There is also an irc channel available for users of this distribution, at
-L<irc://irc.perl.org/#distzilla>.
+L<C<#distzilla> on C<irc.perl.org>|irc://irc.perl.org/#distzilla>.
 
 I am also usually active on irc, as 'ether' at C<irc.perl.org>.
 
